==> jc-1.4.0.tar.gz: java/rmi/server/RMIClassLoaderSpi.h <==
// public abstract class java.rmi.server.RMIClassLoaderSpi

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ad508198824bfd75 java_rmi_server_RMIClassLoaderSpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_server_RMIClassLoaderSpi_H_
#define _JC_java_rmi_server_RMIClassLoaderSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_server_RMIClassLoaderSpi$sub_refs	_jc_java_rmi_server_RMIClassLoaderSpi$sub_refs;
typedef struct _jc_java_rmi_server_RMIClassLoaderSpi$sub_nonrefs	_jc_java_rmi_server_RMIClassLoaderSpi$sub_nonrefs;
typedef struct _jc_java_rmi_server_RMIClassLoaderSpi$refs	_jc_java_rmi_server_RMIClassLoaderSpi$refs;
typedef struct _jc_java_rmi_server_RMIClassLoaderSpi$nonrefs	_jc_java_rmi_server_RMIClassLoaderSpi$nonrefs;
typedef struct _jc_java_rmi_server_RMIClassLoaderSpi$object	_jc_java_rmi_server_RMIClassLoaderSpi$object;

typedef const struct _jc_java_rmi_server_RMIClassLoaderSpi$vmethods	_jc_java_rmi_server_RMIClassLoaderSpi$vmethods;
typedef const struct _jc_java_rmi_server_RMIClassLoaderSpi$vtable	_jc_java_rmi_server_RMIClassLoaderSpi$vtable;
typedef const struct _jc_java_rmi_server_RMIClassLoaderSpi$vtype	_jc_java_rmi_server_RMIClassLoaderSpi$vtype;

// Constructors
extern void _jc_java_rmi_server_RMIClassLoaderSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_server_RMIClassLoaderSpi$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_rmi_server_RMIClassLoaderSpi$method$getClassAnnotation$020ff507b131fc12(_jc_env *, struct _jc_java_rmi_server_RMIClassLoaderSpi$object *, struct _jc_java_lang_Class$object *);
extern struct _jc_java_lang_ClassLoader$object *_jc_java_rmi_server_RMIClassLoaderSpi$method$getClassLoader$0fd2e29b1654b3ef(_jc_env *, struct _jc_java_rmi_server_RMIClassLoaderSpi$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_Class$object *_jc_java_rmi_server_RMIClassLoaderSpi$method$loadClass$76986ad3954c1ff6(_jc_env *, struct _jc_java_rmi_server_RMIClassLoaderSpi$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_ClassLoader$object *);
extern struct _jc_java_lang_Class$object *_jc_java_rmi_server_RMIClassLoaderSpi$method$loadProxyClass$c9ced73d270fc7ed(_jc_env *, struct _jc_java_rmi_server_RMIClassLoaderSpi$object *, struct _jc_java_lang_String$object *, struct _jc_object_array *, struct _jc_java_lang_ClassLoader$object *);

// Virtual method descriptors
extern _jc_method _jc_java_rmi_server_RMIClassLoaderSpi$method_info$getClassAnnotation$020ff507b131fc12;
extern _jc_method _jc_java_rmi_server_RMIClassLoaderSpi$method_info$getClassLoader$0fd2e29b1654b3ef;
extern _jc_method _jc_java_rmi_server_RMIClassLoaderSpi$method_info$loadClass$76986ad3954c1ff6;
extern _jc_method _jc_java_rmi_server_RMIClassLoaderSpi$method_info$loadProxyClass$c9ced73d270fc7ed;

// Virtual methods structure
struct _jc_java_rmi_server_RMIClassLoaderSpi$vmethods {
	struct _jc_java_lang_String$object	*(*getClassAnnotation$020ff507b131fc12)(_jc_env *, struct _jc_java_rmi_server_RMIClassLoaderSpi$object *, struct _jc_java_lang_Class$object *);
	struct _jc_java_lang_ClassLoader$object	*(*getClassLoader$0fd2e29b1654b3ef)(_jc_env *, struct _jc_java_rmi_server_RMIClassLoaderSpi$object *, struct _jc_java_lang_String$object *);
	struct _jc_java_lang_Class$object	*(*loadClass$76986ad3954c1ff6)(_jc_env *, struct _jc_java_rmi_server_RMIClassLoaderSpi$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_ClassLoader$object *);
	struct _jc_java_lang_Class$object	*(*loadProxyClass$c9ced73d270fc7ed)(_jc_env *, struct _jc_java_rmi_server_RMIClassLoaderSpi$object *, struct _jc_java_lang_String$object *, struct _jc_object_array *, struct _jc_java_lang_ClassLoader$object *);
};

// Vtable
struct _jc_java_rmi_server_RMIClassLoaderSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_RMIClassLoaderSpi$vmethods	java_rmi_server_RMIClassLoaderSpi;
};

// Vtype
struct _jc_java_rmi_server_RMIClassLoaderSpi$vtype {
	_jc_type			type;
	_jc_java_rmi_server_RMIClassLoaderSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_RMIClassLoaderSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_server_RMIClassLoaderSpi$refs {
    _jc_java_rmi_server_RMIClassLoaderSpi$sub_refs	java_rmi_server_RMIClassLoaderSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_RMIClassLoaderSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_RMIClassLoaderSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_RMIClassLoaderSpi$sub_nonrefs	java_rmi_server_RMIClassLoaderSpi;
};

// Object instance structure
struct _jc_java_rmi_server_RMIClassLoaderSpi$object {
	_jc_java_rmi_server_RMIClassLoaderSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_RMIClassLoaderSpi$vtype	*vtype;
	_jc_java_rmi_server_RMIClassLoaderSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_RMIClassLoaderSpi$vtype _jc_java_rmi_server_RMIClassLoaderSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_RMIClassLoaderSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_RMIClassLoaderSpi$class_object;

#endif	/* _JC_java_rmi_server_RMIClassLoaderSpi_H_ */

==> jc-1.4.6.tar.gz: java/rmi/server/RMIClassLoaderSpi.h <==
// public abstract class java.rmi.server.RMIClassLoaderSpi

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ad508198824bfd75 java_rmi_server_RMIClassLoaderSpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_server_RMIClassLoaderSpi_H_
#define _JC_java_rmi_server_RMIClassLoaderSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_server_RMIClassLoaderSpi$sub_refs	_jc_java_rmi_server_RMIClassLoaderSpi$sub_refs;
typedef struct _jc_java_rmi_server_RMIClassLoaderSpi$sub_nonrefs	_jc_java_rmi_server_RMIClassLoaderSpi$sub_nonrefs;
typedef struct _jc_java_rmi_server_RMIClassLoaderSpi$refs	_jc_java_rmi_server_RMIClassLoaderSpi$refs;
typedef struct _jc_java_rmi_server_RMIClassLoaderSpi$nonrefs	_jc_java_rmi_server_RMIClassLoaderSpi$nonrefs;
typedef struct _jc_java_rmi_server_RMIClassLoaderSpi$object	_jc_java_rmi_server_RMIClassLoaderSpi$object;

typedef const struct _jc_java_rmi_server_RMIClassLoaderSpi$vmethods	_jc_java_rmi_server_RMIClassLoaderSpi$vmethods;
typedef const struct _jc_java_rmi_server_RMIClassLoaderSpi$vtable	_jc_java_rmi_server_RMIClassLoaderSpi$vtable;
typedef const struct _jc_java_rmi_server_RMIClassLoaderSpi$vtype	_jc_java_rmi_server_RMIClassLoaderSpi$vtype;

// Constructors
extern void _jc_java_rmi_server_RMIClassLoaderSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_server_RMIClassLoaderSpi$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_rmi_server_RMIClassLoaderSpi$method$getClassAnnotation$020ff507b131fc12(_jc_env *, struct _jc_java_rmi_server_RMIClassLoaderSpi$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_ClassLoader$object *_jc_java_rmi_server_RMIClassLoaderSpi$method$getClassLoader$0fd2e29b1654b3ef(_jc_env *, struct _jc_java_rmi_server_RMIClassLoaderSpi$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_java_rmi_server_RMIClassLoaderSpi$method$loadClass$76986ad3954c1ff6(_jc_env *, struct _jc_java_rmi_server_RMIClassLoaderSpi$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_ClassLoader$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_java_rmi_server_RMIClassLoaderSpi$method$loadProxyClass$c9ced73d270fc7ed(_jc_env *, struct _jc_java_rmi_server_RMIClassLoaderSpi$object *, struct _jc_java_lang_String$object *, struct _jc_object_array *, struct _jc_java_lang_ClassLoader$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_rmi_server_RMIClassLoaderSpi$method_info$getClassAnnotation$020ff507b131fc12;
extern _jc_method _jc_java_rmi_server_RMIClassLoaderSpi$method_info$getClassLoader$0fd2e29b1654b3ef;
extern _jc_method _jc_java_rmi_server_RMIClassLoaderSpi$method_info$loadClass$76986ad3954c1ff6;
extern _jc_method _jc_java_rmi_server_RMIClassLoaderSpi$method_info$loadProxyClass$c9ced73d270fc7ed;

// Virtual methods structure
struct _jc_java_rmi_server_RMIClassLoaderSpi$vmethods {
	struct _jc_java_lang_String$object	*(*getClassAnnotation$020ff507b131fc12)(_jc_env *, struct _jc_java_rmi_server_RMIClassLoaderSpi$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_ClassLoader$object	*(*getClassLoader$0fd2e29b1654b3ef)(_jc_env *, struct _jc_java_rmi_server_RMIClassLoaderSpi$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Class$object	*(*loadClass$76986ad3954c1ff6)(_jc_env *, struct _jc_java_rmi_server_RMIClassLoaderSpi$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_ClassLoader$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Class$object	*(*loadProxyClass$c9ced73d270fc7ed)(_jc_env *, struct _jc_java_rmi_server_RMIClassLoaderSpi$object *, struct _jc_java_lang_String$object *, struct _jc_object_array *, struct _jc_java_lang_ClassLoader$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_rmi_server_RMIClassLoaderSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_RMIClassLoaderSpi$vmethods	java_rmi_server_RMIClassLoaderSpi;
};

// Vtype
struct _jc_java_rmi_server_RMIClassLoaderSpi$vtype {
	_jc_type			type;
	_jc_java_rmi_server_RMIClassLoaderSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_RMIClassLoaderSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_server_RMIClassLoaderSpi$refs {
    _jc_java_rmi_server_RMIClassLoaderSpi$sub_refs	java_rmi_server_RMIClassLoaderSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_RMIClassLoaderSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_RMIClassLoaderSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_RMIClassLoaderSpi$sub_nonrefs	java_rmi_server_RMIClassLoaderSpi;
};

// Object instance structure
struct _jc_java_rmi_server_RMIClassLoaderSpi$object {
	_jc_java_rmi_server_RMIClassLoaderSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_RMIClassLoaderSpi$vtype	*vtype;
	_jc_java_rmi_server_RMIClassLoaderSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_RMIClassLoaderSpi$vtype _jc_java_rmi_server_RMIClassLoaderSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_RMIClassLoaderSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_RMIClassLoaderSpi$class_object;

#endif	/* _JC_java_rmi_server_RMIClassLoaderSpi_H_ */
